FeatureGenerator class

Responsibility: Scaffolds a new feature module with Presentation, Domain, and Data layers. Generates base screens, repository contracts, implementation scripts, and registers dependency DI.

Constructors

FeatureGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate({required String featureName, required bool includeData, required bool includeRoutes}) Future<void>
generateFeature(String projectPath, String featureName) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited