ProjectGenerator class

Responsibility: Generates the initial project architecture layout. Scaffolds folders, creates forge.yaml, injects packages into pubspec.yaml, and adds core/ directories.

Constructors

ProjectGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate({required String projectName, required String path, required String stateManagement, required String router}) Future<void>
injectArchitectureFolders(String projectPath) Future<void>
installDependencies(String projectPath) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scaffoldApiResult(String projectPath) Future<void>
scaffoldAppException(String projectPath) Future<void>
scaffoldDioClient(String projectPath) Future<void>
scaffoldExceptionMapper(String projectPath) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited