FinalProjectBlueprint class

Constructors

FinalProjectBlueprint({required String stateManagement, required String routing, required String sessionStrategy, required String environmentStrategy})
const

Properties

environmentStrategy String
final
hashCode int
The hash code for this object.
no setterinherited
routing String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionStrategy String
final
stateManagement String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited