ProjectConfiguration class
Constructors
- ProjectConfiguration({required String projectName, required DateTime createdAt, required ProjectRequirements requirements})
-
const
-
ProjectConfiguration.fromJson(Map<
String, dynamic> json) -
factory
Properties
- createdAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectName → String
-
final
- requirements → ProjectRequirements
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited