ProjectRequirements class
Constructors
- ProjectRequirements({required String stateManagement, required String routing, required String projectScale, required String screenCount, required bool authenticationRequired, required bool sessionRequired, required String environmentSetup})
-
const
-
ProjectRequirements.fromJson(Map<
String, dynamic> json) -
factory
Properties
- authenticationRequired → bool
-
final
- environmentSetup → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectScale → String
-
final
- routing → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenCount → String
-
final
- sessionRequired → bool
-
final
- stateManagement → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited