RecommendationRule class

Constructors

RecommendationRule({required String category, required String trigger, required String recommendation, required String alternative, required String description})
const

Properties

alternative String
final
category String
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
recommendation String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trigger String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited