DeveloperSelectionService class

Constructors

DeveloperSelectionService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept(ArchitectureRecommendation recommendation) DeveloperSelection
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overrideSelection(ArchitectureRecommendation recommendation, {String? stateManagement, String? routing, String? sessionStrategy, String? environmentStrategy}) DeveloperSelection
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited