services/flutter_service library
Responsibility: Runs flutter create and validates Flutter installation. Interacts with local system shell to run flutter sdk actions (e.g. pub get).
Responsibility: Runs flutter create and validates Flutter installation. Interacts with local system shell to run flutter sdk actions (e.g. pub get).