FlutterService class

Constructors

FlutterService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createFlutterProject(String projectName) Future<void>
createProject({required String projectName, required String path}) Future<void>
getFlutterVersion() Future<String>
isFlutterInstalled() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runPubGet({required String path}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited