ProjectBlueprintService class
Constructors
- ProjectBlueprintService({ArchitectureRecommendationService? recommendationService, DeveloperSelectionService? selectionService, TechnologyCompatibilityService? compatibilityService})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildBlueprint(
ProjectConfiguration config, {String? overrideStateManagement, String? overrideRouting, String? overrideSessionStrategy, String? overrideEnvironmentStrategy}) → Future< FinalProjectBlueprint> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited