YesNoQuestion class

Inheritance

Constructors

YesNoQuestion({required String text, required String key})

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
finalinherited

Methods

ask() → dynamic
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited