TechnologyCompatibilityService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConflicts(
TechnologyCompatibility compatibility) → List< String> -
isCompatible(
TechnologyCompatibility compatibility) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
TechnologyCompatibility compatibility) → bool
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited